@@ -35,7 +35,7 @@ test_that('properly creates the xpdb when using the file argument', {
                        gg_theme = theme_readable_221, quiet = TRUE)
   expect_true(inherits(xpdb_1, 'xpose_data'))
   
-  skip_on_cran() # Prevent issues in the absence of long double
+  skip_on_cran() # Skip to avoid issue with no long double
   
   # Correct path and quiet option for identical comparison with xpdb_ex_pk
   xpdb_1$summary$value[xpdb_1$summary$label == 'dir'] <- 'analysis/models/pk/' 
@@ -52,7 +52,7 @@ test_that('properly creates the xpdb when using the runno argument', {
                        gg_theme = theme_readable_221, quiet = TRUE)
   expect_true(inherits(xpdb_2, 'xpose_data'))
   
-  skip_on_cran() # Prevent issues in the absence of long double
+  skip_on_cran() # Skip to avoid issue with no long double
   
   # Correct path and quiet option for identical comparison with xpdb_ex_pk
   xpdb_2$summary$value[xpdb_2$summary$label == 'dir'] <- 'analysis/models/pk/'
